@@ -8,7 +8,8 @@
 #' that can then be printed, plotted, and examined further.
 #'
 #' The criterion and predictor variables are specified in \code{\link{formula}} notation.
-#' Based on the settings of \code{data} and \code{data.test}, FFTs are trained on a (required) training dataset and tested on an (optional) test dataset.
+#' Based on the settings of \code{data} and \code{data.test}, FFTs are trained on a (required) training dataset
+#' (given the set of current \code{goal} values) and evaluated on (or predict) an (optional) test dataset.
 #'
 #' If an existing \code{FFTrees} object \code{object} or \code{tree.definitions} are provided as inputs,
 #' no new FFTs are created.
@@ -24,53 +25,76 @@
 #'
 #' }
 #'
-#' @param formula formula. A \code{\link{formula}} specifying a binary criterion variable (as logical) as a function of 1 or more predictor variables (cues).
-#' @param data dataframe. A training dataset.
-#' @param data.test dataframe. An optional testing dataset with the same structure as data.
-#' @param algorithm character. The algorithm used to create FFTs. Can be \code{'ifan'}, \code{'dfan'}.
-#' @param max.levels integer. The maximum number of levels considered for the trees. Because all permutations of exit structures are considered, the larger \code{max.levels} is, the more trees will be created.
-#' @param sens.w numeric. A number from 0 to 1 indicating how to weight sensitivity relative to specificity when \code{goal = 'wacc'}. Default: \code{sens.w = .50}.
+#' @param formula A formula. A \code{\link{formula}} specifying a binary criterion variable (as logical) as a function of 1 or more predictor variables (cues).
+#' @param data A data frame. A dataset used for training (fitting) FFTs and alternative algorithms.
+#' \code{data} must contain the binary criterion variable specified in \code{formula} and potential predictors (which can be categorical or numeric variables).
+#' @param data.test A data frame. An optional dataset used for model testing (prediction) with the same structure as data.
+#' @param algorithm A character string. The algorithm used to create FFTs. Can be \code{'ifan'}, \code{'dfan'}.
+#' @param train.p numeric. What percentage of the data to use for training when \code{data.test} is not specified?
+#' For example, \code{train.p = .50} will randomly split \code{data} into a 50\% training set and a 50\% test set.
+#' Default: \code{train.p = 1} (i.e., using \emph{all} data for training).
 #'
-#' @param cost.outcomes A list of length 4 specifying the cost value for one of the 4 possible classification outcomes.
-#' The list elements must have names \code{'hi'}, \code{'fa'}, \code{'mi'}, and \code{'cr'}
-#' (for specifying the costs of a hit, false alarm, miss, and correct rejection, respectively) and provide a numeric cost value.
-#' E.g.; \code{cost.outcomes = listc("hi" = 0, "fa" = 10, "mi" = 20, "cr" = 0)} means that a false alarm and miss cost 10 and 20, respectively, while correct decisions have no costs.
-#' @param cost.cues A list containing the cost of each cue (in some unit).
-#' Each list element must have a name corresponding to a cue (i.e., a column in \code{data}), and should be a single (positive) number.
-#' Cues not present in \code{cost.cues} are assumed to have no costs (i.e., a cost value of 0).
+#' @param goal A character string indicating the statistic to maximize when \emph{selecting trees}:
+#' \code{"acc"} = overall accuracy, \code{"bacc"} = balanced accuracy, \code{"wacc"} = weighted accuracy,
+#' \code{"dprime"} = discriminability, \code{"cost"} = costs (based on \code{cost.outcomes} and \code{cost.cues}).
+#' @param goal.chase A character string indicating the statistic to maximize when \emph{constructing trees}:
+#' \code{"acc"} = overall accuracy, \code{"bacc"} = balanced accuracy, \code{"wacc"} = weighted accuracy,
+#' \code{"dprime"} = discriminability, \code{"cost"} = costs (based on \code{cost.outcomes} and \code{cost.cues}).
+#' @param goal.threshold A character string indicating the criterion to maximize when \emph{optimizing cue thresholds}:
+#' \code{"acc"} = overall accuracy, \code{"bacc"} = balanced accuracy, \code{"wacc"} = weighted accuracy,
+#' \code{"dprime"} = discriminability, \code{"cost"} = costs (based only on \code{cost.outcomes}, as \code{cost.cues} are constant per cue).
+#' All default goals are set in \code{\link{fftrees_create}}.
 #'
-#' @param stopping.rule character. A string indicating the method to stop growing trees.
+#' @param max.levels integer. The maximum number of nodes (or levels) considered for an FFT.
+#' As all combinations of possible exit structures are considered, larger values of \code{max.levels} will create larger sets of FFTs.
+#' @param numthresh.method character. How should thresholds for numeric cues be determined?
+#' \code{"o"} will optimize thresholds, while \code{"m"} will always use the median.
+#' @param numthresh.n integer. The number of numeric thresholds to try.
+#' @param repeat.cues logical. May cues occur multiple times within a tree?
+#' Default: \code{repeat.cues = TRUE}.
+#' A value of \code{0} rounds all possible thresholds to the nearest integer, \code{1} rounds to the nearest decade (.10), etc.
+#' @param stopping.par numeric. A numeric value indicating the parameter for the stopping rule.
+#' For stopping.rule \code{"levels"}, this is the number of levels.
+#' For stopping rule \code{"exemplars"}, this is the smallest percentage of exemplars allowed in the last level.
+#' Default: \code{stopping.par = .10}.
+#' @param stopping.rule character. A character string indicating the method to stop growing trees. Available options are:
 #' \code{"levels"} means the tree grows until a certain level;
 #' \code{"exemplars"} means the tree grows until a certain number of unclassified exemplars remain;
 #' \code{"statdelta"} means the tree grows until the change in the criterion statistic is less than a specified level.
-#' @param stopping.par numeric. A number indicating the parameter for the stopping rule.
-#' For stopping.rule \code{"levels"}, this is the number of levels.
-#' For stopping rule \code{"exemplars"}, this is the smallest percentage of exemplars allowed in the last level.
 #'
-#' @param goal character. A string indicating the statistic to maximize when selecting final trees: \code{"acc"} = overall accuracy, \code{"bacc"} = balanced accuracy, \code{"wacc"} = weighted accuracy.
-#' @param goal.chase character. A string indicating the statistic to maximize when constructing trees: \code{"acc"} = overall accuracy, \code{"bacc"} = balanced accuracy, \code{"wacc"} = weighted accuracy, \code{"cost"} = cue costs.
-#' @param goal.threshold character. A string indicating the statistic to maximize when calculating cue thresholds: \code{"acc"} = overall accuracy, \code{"bacc"} = balanced accuracy, \code{"wacc"} = weighted accuracy.
-#' Default: \code{goal.threshold = "bacc"}.
+#' @param sens.w A numeric value from \code{0} to \code{1} indicating how to weight
+#' sensitivity relative to specificity when optimizing \emph{weighted} accuracy (e.g., \code{goal = 'wacc'}).
+#' Default: \code{sens.w = .50} (i.e., \code{wacc} corresponds to \code{bacc}).
+#'
+#' @param cost.outcomes A list of length 4 specifying the cost value for one of the 4 possible classification outcomes.
+#' The list elements must be named \code{'hi'}, \code{'fa'}, \code{'mi'}, and \code{'cr'}
+#' (for specifying the costs of a hit, false alarm, miss, and correct rejection, respectively) and provide a numeric cost value.
+#' E.g.; \code{cost.outcomes = listc("hi" = 0, "fa" = 10, "mi" = 20, "cr" = 0)} imposes false alarm and miss costs of \code{10} and \code{20} units, respectively, while correct decisions have no costs.
+#' @param cost.cues A list containing the cost of each cue (in some common unit).
+#' Each list element must have a name corresponding to a cue (i.e., a variable in \code{data}), and should be a single (positive numeric) value.
+#' Cues in \code{data} that are not present in \code{cost.cues} are assumed to have no costs (i.e., a cost value of \code{0}).
 #'
-#' @param numthresh.method character. How should thresholds for numeric cues be determined? \code{"o"} will optimize thresholds, while \code{"m"} will always use the median.
-#' @param numthresh.n integer. Number of numeric thresholds to try.
-#' @param decision.labels string. A vector of strings of length 2 indicating labels for negative and positive cases. E.g.; \code{decision.labels = c("Healthy", "Diseased")}.
 #' @param main string. An optional label for the dataset. Passed on to other functions, like \code{\link{plot.FFTrees}}, and \code{\link{print.FFTrees}}.
-#' @param train.p numeric. What percentage of the data to use for training when \code{data.test} is not specified?
-#' For example, \code{train.p = .50} will randomly split \code{data} into a 50\% training set and a 50\% test set.
-#' The default of \code{train.p = 1} uses all data for training.
-#' @param rounding integer. An integer indicating digit rounding for non-integer numeric cue thresholds.
-#' The default of \code{rounding = NULL} implies no rounding.
-#' A value of \code{0} rounds all possible thresholds to the nearest integer, \code{1} rounds to the nearest decade (.10), etc.
-#' @param repeat.cues logical. May cues occur multiple times within a tree? Default: \code{repeat.cues = TRUE}.
+#' @param decision.labels string. A vector of strings of length 2 indicating labels for negative and positive cases. E.g.; \code{decision.labels = c("Healthy", "Diseased")}.
+#'
+#' @param my.goal The name of an optimization measure defined by \code{my.goal.fun} (as a character string).
+#' Example: \code{my.goal = "my_acc"} (see \code{my.goal.fun} for corresponding function).
+#' Default: \code{my.goal = NULL}.
+#' @param my.goal.fun The definition of an outcome measure to optimize, defined as a function
+#' of the frequency counts of the 4 basic classification outcomes \code{hi, fa, mi, cr}
+#' (i.e., an R function with 4 arguments \code{hi, fa, mi, cr}).
+#' Example: \code{my.goal.fun = function(hi, fa, mi, cr){(hi + cr)/(hi + fa + mi + cr)}} (i.e., accuracy).
+#' Default: \code{my.goal.fun = NULL}.
+#'
+#' @param my.tree A verbal description of an FFT, i.e., an "FFT in words" (as character string).
+#' For example, \code{my.tree = "If age > 20, predict TRUE. If sex = {m}, predict FALSE. Otherwise, predict TRUE."}.
 #'
-#' @param my.tree An optional character string. A a verbal description of an FFT, i.e., an FFT in words.
-#' For example, \code{my.tree = "If age > 20, predict TRUE. If sex = {m}, predict FALSE. Otherwise, predict TRUE."}
 #' @param object An optional existing \code{FFTrees} object.
 #' When specified, no new FFTs are fitted, but existing trees are applied to \code{data} and \code{data.test}.
 #' When \code{formula}, \code{data} or \code{data.test} are not specified, the current values of \code{object} are used.
 #' @param tree.definitions An optional \code{data.frame} of hard-coded FFT definitions (in the format of \code{x$trees$definitions} of an \code{FFTrees} object \code{x}).
-#' If specified, no new FFTs are fitted, but the tree definitions provided are used to re-evaluate the current \code{FFTrees} object.
+#' If specified, no new FFTs are being fitted (i.e., \code{algorithm} and functions for evaluating cues and creating FFTs are skipped).
+#' Instead, the tree definitions provided are used to re-evaluate the current \code{FFTrees} object on current data.
 #'
 #' @param do.comp,do.cart,do.lr,do.rf,do.svm logical. Should alternative algorithms be used for comparison?
 #' All options set to \code{TRUE} by default. Available options are:
@@ -80,10 +104,11 @@
 #' \code{svm} = support vector machines with \strong{e1071}.
 #' Specifying \code{do.comp = FALSE} sets all available options to \code{FALSE}.
 #'
-#' @param quiet logical. Should progress reports be suppressed? Setting \code{quiet = FALSE} is helpful for diagnosing errors.
+#' @param quiet logical. Should progress reports be suppressed?
+#' Setting \code{quiet = FALSE} is helpful for diagnosing errors.
 #' Default: \code{quiet = FALSE} (i.e., show progress).
 #'
-#' @param comp,force,rank.method,store.data,verbose Deprecated arguments (unused or replaced, to be retired in future releases).
+#' @param comp,force,rank.method,rounding,store.data,verbose Deprecated arguments (unused or replaced, to be retired in future releases).
 #'
 #' @return An \code{FFTrees} object with the following elements:
 #' \describe{
@@ -149,28 +174,33 @@
 FFTrees <- function(formula = NULL,
                     data = NULL,
                     data.test = NULL,
-                    #
                     algorithm = "ifan",
-                    max.levels = NULL,
-                    sens.w = .50,
-                    cost.outcomes = NULL,
-                    cost.cues = NULL,
-                    stopping.rule = "exemplars",
-                    stopping.par = .1,
+                    train.p = 1,
                     #
-                    goal = NULL,  # (default set in fftrees_create.R)
-                    goal.chase = NULL,  # (default set in fftrees_create.R)
-                    goal.threshold = "bacc",  # default
+                    goal = NULL,              # (default set in fftrees_create.R)
+                    goal.chase = NULL,        # (default set in fftrees_create.R)
+                    goal.threshold = NULL,    # (default set in fftrees_create.R)
+                    #
+                    max.levels = NULL,        # (default set in fftrees_create.R)
                     numthresh.method = "o",
                     numthresh.n = 10,
-                    #
-                    decision.labels = c("False", "True"),  # in 0:left/1:right order!
-                    main = NULL,
-                    train.p = 1,
-                    rounding = NULL,
                     repeat.cues = TRUE,
+                    stopping.par = .10,
+                    stopping.rule = "exemplars",
                     #
+                    sens.w = .50,
+                    #
+                    cost.outcomes = NULL,     # (default set in fftrees_create.R)
+                    cost.cues = NULL,         # (default set in fftrees_create.R)
+                    #
+                    main = NULL,
+                    decision.labels = c("False", "True"),  # in 0:FALSE/noise/left vs. 1:TRUE/signal/right order
+                    #
+                    #
+                    my.goal = NULL,      # e.g., "my_acc",  # name of my.goal (as character)
+                    my.goal.fun = NULL,  # e.g., function(hi, fa, mi, cr){(hi + cr)/(hi + fa + mi + cr)},  # a function of (hi, fa, mi, cr)
                     my.tree = NULL,
+                    #
                     object = NULL,
                     tree.definitions = NULL,
                     #
@@ -186,13 +216,14 @@ FFTrees <- function(formula = NULL,
                     comp = NULL,         # do.comp
                     force = NULL,        # (none)
                     rank.method = NULL,  # algorithm
+                    rounding = NULL,     # in fftrees_cuerank()
                     store.data = NULL,   # (none)
                     verbose = NULL       # progress
 ) {
 
   # Prepare: ------
 
-  # A. Handle deprecated arguments and options: ----
+  # A. Handle deprecated arguments and options: ------
 
   if (!is.null(comp)) {
     warning("The argument 'comp' is deprecated. Use 'do.comp' instead.")
@@ -210,6 +241,10 @@ FFTrees <- function(formula = NULL,
     algorithm <- rank.method
   }
 
+  if (!is.null(rounding)) {
+    warning("The argument 'rounding' is deprecated and ignored.")
+  }
+
   if (!is.null(store.data)) {
     warning("The argument 'store.data' is deprecated and ignored.")
   }
@@ -225,7 +260,9 @@ FFTrees <- function(formula = NULL,
   }
 
 
-  # B. Verify inputs: ----
+  # B. Verify inputs: ------
+
+  # object: ----
 
   if (!is.null(object)) { # an FFTrees object is provided:
 
@@ -233,26 +270,62 @@ FFTrees <- function(formula = NULL,
     testthat::expect_s3_class(object, class = "FFTrees")
 
     # Fill in some missing defaults by current object values:
-    if (is.null(formula)){ formula <- object$formula }
+
+    # Main formula and data parameters (to keep/preserve):
+    if (is.null(formula)) { formula <- object$formula }
     if (is.null(data)) { data <- object$data$train }
     if (is.null(data.test) & (!is.null(object$data$test))) { data.test <- object$data$test }
 
-    # Other candidates: goal and threshold parameters.
+    # goal parameters:
+    if (is.null(goal)) { goal <- object$params$goal }
+    if (is.null(goal.chase)) { goal.chase <- object$params$goal.chase }
+    if (is.null(goal.threshold)) { goal.threshold <- object$params$goal.threshold }
+
+    # cost parameters:
+    if (is.null(cost.outcomes)) { cost.outcomes <- object$params$cost.outcomes }
+    if (is.null(cost.cues)) { cost.cues <- object$params$cost.cues }
+
+    # Other candidates (of parameters to keep/preserve):
+    # numthresh, stopping, ...
+    if (is.null(algorithm)) { algorithm <- object$params$algorithm }
+    if (is.null(max.levels)) { max.levels <- object$params$max.levels }
+
+    # Provide user feedback: ----
+
+    if (!quiet) {
+      msg <- paste0("Using the FFTrees object provided (and some of its key parameters).\n")
+      cat(u_f_hig(msg))
+    }
 
   }
 
+
+  # tree.definitions: ----
+
   if (!is.null(tree.definitions)){
 
-    testthat::expect_true(is.data.frame(tree.definitions), info = "Provided 'tree.definitions' are not a data.frame")
+    # Verify:
 
     # ToDo: Verify integrity of tree definitions:
-    # 1. tree.definitions contains valid tree definitions (in appropriate format)
+    # 1. tree.definitions contains valid tree definitions (in appropriate format):
+    testthat::expect_true(verify_fft_definition(tree.definitions))
+
     # 2. tree.definitions fit to provided data (see verify_all_cues_in_data() in helper.R)
 
   }
 
 
-  # C. Handle data: ----
+  # formula: ----
+
+  # Get criterion (from formula):
+  criterion_name <- get_lhs_formula(formula)
+
+  if (!criterion_name %in% names(data)){
+    stop(paste0("Criterion variable '", criterion_name, "' was not found in data"))
+  }
+
+
+  # C. Handle data: ------
 
   # # Convert factor NA to new missing factor level:
   #
@@ -268,8 +341,7 @@ FFTrees <- function(formula = NULL,
     # Save original data:
     data_o <- data
 
-    train_cases <- caret::createDataPartition(data_o[[paste(formula)[2]]],
-                                              p = train.p)[[1]]
+    train_cases <- caret::createDataPartition(data_o[[criterion_name]], p = train.p)[[1]]
 
     data      <- data_o[train_cases, ]
     data.test <- data_o[-train_cases, ]
@@ -279,7 +351,7 @@ FFTrees <- function(formula = NULL,
 
     if (!quiet) {
       msg <- paste0("Successfully split data into a ", scales::percent(train.p), " (N = ", scales::comma(nrow(data)), ") training and ",
-        scales::percent(1 - train.p), " (N = ", scales::comma(nrow(data.test)), ") test set.\n")
+                    scales::percent(1 - train.p), " (N = ", scales::comma(nrow(data.test)), ") test set.\n")
       cat(u_f_fin(msg))
     }
 
@@ -290,31 +362,41 @@ FFTrees <- function(formula = NULL,
 
   # 1. Create a new FFTrees object x: ----
 
-  x <- fftrees_create(data = data,
-                      formula = formula,
+  x <- fftrees_create(formula = formula,
+                      data = data,
                       data.test = data.test,
                       algorithm = algorithm,
+                      #
                       goal = goal,
                       goal.chase = goal.chase,
                       goal.threshold = goal.threshold,
-                      sens.w = sens.w,
+                      #
                       max.levels = max.levels,
-                      cost.outcomes = cost.outcomes,
-                      cost.cues = cost.cues,
-                      stopping.rule = stopping.rule,
-                      stopping.par = stopping.par,
-                      decision.labels = decision.labels,
-                      main = main,
-                      my.tree = my.tree,
-                      repeat.cues = repeat.cues,
                       numthresh.method = numthresh.method,
                       numthresh.n = numthresh.n,
+                      stopping.rule = stopping.rule,
+                      stopping.par = stopping.par,
+                      repeat.cues = repeat.cues,
+                      #
+                      sens.w = sens.w,
+                      #
+                      cost.outcomes = cost.outcomes,
+                      cost.cues = cost.cues,
+                      #
+                      main = main,
+                      decision.labels = decision.labels,
+                      #
+                      my.goal = my.goal,
+                      my.goal.fun = my.goal.fun,
+                      my.tree = my.tree,
+                      #
                       do.lr   = do.lr,
                       do.cart = do.cart,
                       do.svm  = do.svm,
                       do.rf   = do.rf,
                       do.comp = do.comp,
-                      quiet = quiet  # store in x$params$quiet
+                      #
+                      quiet = quiet # stored in x$params$quiet
   )
 
 
@@ -366,4 +448,10 @@ FFTrees <- function(formula = NULL,
 # - When providing a valid FFTrees object:
 #   Fill in missing defaults (formula, data, ...) with corresponding object values.
 
+# Note source of confusion: The `tree` variable in tree definitions sometimes serves as:
+# 1. a counter (`tree_i` in `fftrees_apply()`), but mostly as
+# 2. an ID variable (i.e., `tree` = 1 is "best" tree after ranking...).
+# ToDo: Assign a separate `tree_id` (which acts as an identifier/name handler for a tree
+#       and is moved with tree definition by ranking.
+
 # eof.
