@@ -16,11 +16,28 @@
 fftrees_ranktrees <- function(x,
                               data = "train") {
 
+  # Prepare: ------
+
+  # Verify inputs: ----
+
+  testthat::expect_s3_class(x, class = "FFTrees")
+  testthat::expect_true(data %in% c("train", "test"))
+
+
   # Initialize: ----
 
   tree_stats <- x$trees$stats[[data]]
 
 
+  # Provide user feedback: ----
+
+  if (!x$params$quiet) {
+    msg <- paste0("Aiming to rank FFTs by '", data, "' data:\n")
+    cat(u_f_ini(msg))
+  }
+  # print(x$trees$definitions) # 4debugging
+
+
   # 1. Rank trees by current goal: ----
 
   if (x$params$goal == "cost") {  # rank by cost:
@@ -55,34 +72,43 @@ fftrees_ranktrees <- function(x,
 
   if (data == "train"){
 
-  # Training stats:
-  x$trees$stats$train <- x$trees$stats$train %>%
-    dplyr::left_join(tree_rank_df, by = "tree") %>%
-    dplyr::select(-tree) %>%
-    dplyr::rename(tree = tree_new) %>%
-    dplyr::select(tree, dplyr::everything()) %>%
-    dplyr::arrange(tree) %>%
-    tibble::as_tibble()
+    # Training stats:
+    x$trees$stats$train <- x$trees$stats$train %>%
+      dplyr::left_join(tree_rank_df, by = "tree") %>%
+      dplyr::select(-tree) %>%
+      dplyr::rename(tree = tree_new) %>%
+      dplyr::select(tree, dplyr::everything()) %>%
+      dplyr::arrange(tree) %>%
+      tibble::as_tibble()
 
-  # Training level_stats:
-  x$trees$level_stats$train <- x$trees$level_stats$train %>%
-    dplyr::left_join(tree_rank_df, by = "tree") %>%
-    dplyr::select(-tree) %>%
-    dplyr::rename(tree = tree_new) %>%
-    dplyr::select(tree, dplyr::everything()) %>%
-    dplyr::arrange(tree, level) %>%
-    tibble::as_tibble()
+    # Training level_stats:
+    x$trees$level_stats$train <- x$trees$level_stats$train %>%
+      dplyr::left_join(tree_rank_df, by = "tree") %>%
+      dplyr::select(-tree) %>%
+      dplyr::rename(tree = tree_new) %>%
+      dplyr::select(tree, dplyr::everything()) %>%
+      dplyr::arrange(tree, level) %>%
+      tibble::as_tibble()
 
-  # Training decisions:
-  x$trees$decisions$train <- x$trees$decisions$train[tree_rank_df$tree]
-  names(x$trees$decisions$train) <- paste0("tree_", 1:nrow(tree_rank_df))
+    # Training decisions:
+    x$trees$decisions$train <- x$trees$decisions$train[tree_rank_df$tree]
+    names(x$trees$decisions$train) <- paste0("tree_", 1:nrow(tree_rank_df))
 
-  # Best training tree:
-  x$trees$best$train <- select_best_tree(x, data = "train", goal = x$params$goal)
+    # Get and set value of best training tree:
+    x$trees$best$train <- get_best_tree(x, data = "train", goal = x$params$goal)
 
   } # if (data == "train").
 
 
+  # Provide user feedback: ----
+
+  if (!x$params$quiet) {
+    msg <- paste0("Successfully ranked FFTs by '", data, "' data.\n")
+    cat(u_f_fin(msg))
+  }
+  # print(x$trees$definitions) # 4debugging
+
+
   # Note: The analog (data == "test") case is currently NOT ranked.
 
 
